@@ -4,7 +4,7 @@
 #' @description
 #'
 #' A dot chart (as described by William S. Cleveland) with statistical details
-#' from one-sample test details.
+#' from one-sample test.
 #'
 #' @param ... Currently ignored.
 #' @param y Label or grouping variable.
@@ -34,8 +34,6 @@
 #' )
 #' }
 #' @export
-
-# function body
 ggdotplotstats <- function(data,
                            x,
                            y,
@@ -105,8 +103,7 @@ ggdotplotstats <- function(data,
       conf.level   = conf.level,
       k            = k,
       tr           = tr,
-      bf.prior     = bf.prior,
-      top.text     = caption
+      bf.prior     = bf.prior
     )
 
     # preparing the subtitle with statistical results
@@ -130,7 +127,6 @@ ggdotplotstats <- function(data,
 
   # plot -----------------------------------
 
-  # creating the basic plot
   plot <- ggplot(data, mapping = aes({{ x }}, y = rank)) +
     exec(geom_point, !!!point.args) +
     scale_y_continuous(
@@ -143,9 +139,9 @@ ggdotplotstats <- function(data,
         labels = 25 * 0:4
       )
     )
+
   # centrality plotting -------------------------------------
 
-  # using custom function for adding labels
   if (isTRUE(centrality.plotting)) {
     plot <- histo_labeller(
       plot,
@@ -159,7 +155,6 @@ ggdotplotstats <- function(data,
 
   # annotations -------------------------
 
-  # specifying theme and labels for the final plot
   plot +
     labs(
       x        = xlab %||% as_name(x),
@@ -212,8 +207,6 @@ ggdotplotstats <- function(data,
 #' )
 #' }
 #' @export
-
-# defining the function
 grouped_ggdotplotstats <- function(data,
                                    ...,
                                    grouping.var,
@@ -234,6 +227,5 @@ grouped_ggdotplotstats <- function(data,
   # combining the list of plots into a single plot
   if (output == "plot") p_ls <- combine_plots(p_ls, plotgrid.args, annotation.args)
 
-  # return the object
   p_ls
 }
