@@ -1,45 +1,32 @@
 # grouped_gghistostats works ---------------------------------------------
 
 test_that(
-  desc = "grouped_gghistostats works",
+  desc = "grouped_gghistostats plotting works as expected",
   code = {
-    skip_on_cran()
-
-    # when arguments are entered as bare expressions
     set.seed(123)
-    expect_true(inherits(
-      grouped_gghistostats(
+    vdiffr::expect_doppelganger(
+      title = "defaults as expected",
+      fig = grouped_gghistostats(
         data = ggplot2::msleep,
         x = brainwt,
         grouping.var = vore,
-        type = "p",
-        results.subtitle = FALSE,
-        normal.curve = TRUE,
-        bar.measure = "mix",
-        bf.message = TRUE
-      ),
-      what = "gg"
-    ))
+        normal.curve = TRUE
+      )
+    )
 
-    # when arguments are entered as character
     set.seed(123)
-    expect_true(inherits(
-      grouped_gghistostats(
+    vdiffr::expect_doppelganger(
+      title = "modification with ggplot2 works",
+      fig = suppressWarnings(grouped_gghistostats(
         data = ggplot2::msleep,
         x = brainwt,
         grouping.var = vore,
-        type = "r",
         results.subtitle = FALSE,
-        normal.curve = TRUE,
-        effsize.type = "d",
-        effsize.noncentral = FALSE,
-        bar.measure = "proportion",
         ggplot.component = ggplot2::scale_x_continuous(
           sec.axis = ggplot2::dup_axis(name = ggplot2::element_blank())
         )
-      ),
-      what = "gg"
-    ))
+      ))
+    )
   }
 )
 
@@ -48,8 +35,6 @@ test_that(
 test_that(
   desc = "subtitle output",
   code = {
-    skip_on_cran()
-
     df <- dplyr::filter(ggplot2::msleep, vore == "omni")
 
     set.seed(123)
@@ -68,7 +53,6 @@ test_that(
       test.value = 0.25
     )$expression[[1]]
 
-    # tests
     expect_equal(ls_results$`omni`, basic_results)
   }
 )
